@@ -24,6 +24,7 @@
 #include "position.h"
 #include "graphics_board_item.h"
 
+#include <QGraphicsSvgItem>
 #include <QString>
 #include <QGraphicsView>
 #include <QGraphicsScene>
@@ -51,41 +52,28 @@ public:
 
     virtual void setScene(QGraphicsScene* scene);
 
-public Q_SLOTS:
-    /* Draws a chess position on this board, by extracting the FEN [1]
-     * representation from the given MPosition.
-     * Each piece (= QGraphicsSvgItem) that is added becomes a child of the board.
-     * [1] http://en.wikipedia.org/wiki/Forsyth%E2%80%93Edwards_Notation
-     */
-    void drawPosition(const MPosition &position);
-    void drawStartPosition();
+    void addBoardItem(MGraphicsBoardItem *item);
 
-Q_SIGNALS:
-    void pieceMoveRequested(QPoint from, QPoint to);
-    void sendDebugInfo(QString msg);
+    /* Takes ownership of the proxy widget. */
+    void setTopActionArea(QGraphicsProxyWidget *proxy_widget);
+    /* Takes ownership of the proxy widget. */
+    void setBottomActionArea(QGraphicsProxyWidget *proxy_widget);
 
 protected:
     virtual void drawBackground(QPainter *painter, const QRectF &region);
 
+private Q_SLOTS:
+    void onLoadFinished(bool ok);
+
 private:
-    void setBoardBackground();
-
-    /* Store a reference to the board item in the scene graph. */
-    MGraphicsBoardItem* m_board_item;
-
-    // A MPiece*-to-QGraphicsSvgItem* mapping, which allows us to cleanly cache
-    // SVG items and to only insert them in the MGraphicsBoardItem once. Done
-    // for mouse event speed optimisation.
-    typedef QHash<MPiece*, QGraphicsSvgItem*> MSvgItemCache;
-    MSvgItemCache m_cache;
+    void setup();
 
     QWebPage* m_background_page;
     QImage* m_background_image;
 
-private Q_SLOTS:
-    void onPieceMoveRequested(QPoint from, QPoint to);
-    void appendDebugOutput(QString msg);
-    void onLoadFinished(bool ok);
+    // Indicates where to position the board item, and where to draw the board
+    // background.
+    const int m_board_item_offset;
 };
 
 }; // namespace Miniature
