@@ -42,7 +42,7 @@ MGame::MGame(MBoardView *view, QObject *parent)
 {
     Q_ASSERT(m_view);
 
-    // process state transition requests
+    // Process state transition requests.
     connect(&m_top_action_area, SIGNAL(moveConfirmed()),
             this, SLOT(onMoveConfirmed()));
     connect(&m_bottom_action_area, SIGNAL(moveConfirmed()),
@@ -52,8 +52,22 @@ MGame::MGame(MBoardView *view, QObject *parent)
     connect(&m_bottom_action_area, SIGNAL(pieceSelectionCancelled()),
             this, SLOT(onPieceSelectionCancelled()));
 
-    m_view->setTopActionArea(m_top_action_area.createActionAreaProxyWidget(QString("qgil")));
-    m_view->setBottomActionArea(m_bottom_action_area.createActionAreaProxyWidget(QString("kore")));
+    m_view->setTopActionArea(m_top_action_area.getProxyWidget());
+    m_view->setBottomActionArea(m_bottom_action_area.getProxyWidget());
+
+    m_top_action_area.setText(QString("qgil"));
+    m_bottom_action_area.setText(QString("kore"));
+
+    // Enable rotation for action areas.
+    connect(this, SIGNAL(turnOfTopPlayer()),
+            &m_top_action_area, SLOT(rotate180()));
+    connect(this, SIGNAL(turnOfTopPlayer()),
+            &m_bottom_action_area, SLOT(rotate180()));
+
+    connect(this, SIGNAL(turnOfBottomPlayer()),
+            &m_top_action_area, SLOT(rotate0()));
+    connect(this, SIGNAL(turnOfBottomPlayer()),
+            &m_bottom_action_area, SLOT(rotate0()));
 
     newGame();
 }
@@ -99,35 +113,35 @@ void MGame::newGame()
     setupBoardItem();
     setupStartPosition();
 
-    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED);
+    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED, true);
 }
 
 void MGame::jumpToStart()
 {
     cleanupTransitionData();
     setPositionTo(0);
-    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED);
+    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED, true);
 }
 
 void MGame::prevMove()
 {
     cleanupTransitionData();
     setPositionTo(m_half_move - 1);
-    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED);
+    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED, true);
 }
 
 void MGame::nextMove()
 {
     cleanupTransitionData();
     setPositionTo(m_half_move + 1);
-    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED);
+    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED, true);
 }
 
 void MGame::jumpToEnd()
 {
     cleanupTransitionData();
     setPositionTo(m_game.size() - 1);
-    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED);
+    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED, true);
 }
 
 void MGame::setupStartPosition()
@@ -185,6 +199,13 @@ void MGame::addPieceToPositionAt(MPiece *piece, MPosition *pos, QPoint cell)
     piece->show();
     // Assign ownership to m_board_item.
     piece->setParentItem(m_board_item);
+
+    // Enable rotation for this piece.
+    connect(this, SIGNAL(turnOfTopPlayer()),
+            piece, SLOT(rotate180()));
+
+    connect(this, SIGNAL(turnOfBottomPlayer()),
+            piece, SLOT(rotate0()));
 }
 
 bool MGame::isValidPosition(int half_move) const
@@ -198,7 +219,7 @@ void MGame::setPositionTo(int half_move)
 
     if (isValidPosition(half_move))
     {
-        deSelectPiece();
+        cleanupTransitionData();
         m_half_move = half_move;
         MPosition pos = m_game[m_half_move];
 
@@ -208,18 +229,31 @@ void MGame::setPositionTo(int half_move)
     }
 }
 
-void MGame::setActionAreaStates(MActionArea::State s1, MActionArea::State s2)
+void MGame::setActionAreaStates(MActionArea::State s1, MActionArea::State s2, bool emit_turn_signal)
 {
     // current mapping is white = bottom
     if (isTurnOfBottomPlayer())
     {
         m_top_action_area.setState(s1);
         m_bottom_action_area.setState(s2);
+
+        if (emit_turn_signal)
+        {
+            Q_EMIT turnOfBottomPlayer();
+        }
     }
     else
     {
         m_top_action_area.setState(s2);
         m_bottom_action_area.setState(s1);
+
+        m_top_action_area.rotate(180);
+        m_bottom_action_area.rotate(180);
+
+        if (emit_turn_signal)
+        {
+            Q_EMIT turnOfTopPlayer();
+        }
     }
 }
 
@@ -234,7 +268,7 @@ bool MGame::isTurnOfBottomPlayer() const
     return (m_half_move % 2 == (m_is_bottom_player_white ? 0 : 1));
 }
 
-void MGame::undoMove()
+void MGame::undoTransitionalMove()
 {
     if (m_selected_piece)
     {
@@ -261,7 +295,7 @@ void MGame::selectPiece(MPiece *piece)
 {
     if (piece)
     {
-        undoMove();
+        undoTransitionalMove();
         deSelectPiece();
         m_selected_piece = piece;
         m_selected_piece->select();
@@ -336,9 +370,11 @@ void MGame::onTargetClicked(const QPoint &target)
     MLogicAnalyzer::MStateFlags result = m_logic_analyzer.verifyMove(&position, origin, target);
     if (MLogicAnalyzer::VALID & result)
     {
+        // TODO: clean up the evaluation of the logic analyzer's result. Try to make it a switch stmt at least.
+
         // Undo any move that was maybe done from the previous m_trans_position,
         // that is, to "reset" the state.
-        undoMove(); // TODO: refine this if moving back is visible to the user ... unlikely
+        undoTransitionalMove(); // TODO: refine this if moving back is visible to the user ... unlikely
         m_trans_position = position;
 
         // TODO: check for capture flag instead.
@@ -348,9 +384,23 @@ void MGame::onTargetClicked(const QPoint &target)
             m_trans_captured_piece = maybe_captured;
         }
 
+        if ((MLogicAnalyzer::CHECK | MLogicAnalyzer::CHECKMATE) & result)
+        {
+            m_trans_position.setInCheck(true);
+        }
         setActionAreaStates(MActionArea::NONE, MActionArea::TARGET_SELECTED);
         m_trans_position.movePiece(origin, target);
 
+        if (MLogicAnalyzer::PROMOTION & result)
+        {
+            MPiece *pawn = m_trans_position.pieceAt(target);
+            if (pawn) // actually silly, the surrounding code already makes sure this is true
+            {
+                MPiece::MColour colour = pawn->getColour();
+                addPieceToPositionAt(new MQueen(colour), &m_trans_position, target);
+            }
+        }
+
         // just example code to visualize check
         if ((MLogicAnalyzer::CHECK | MLogicAnalyzer::CHECKMATE) & result)
         {
@@ -362,6 +412,11 @@ void MGame::onTargetClicked(const QPoint &target)
         }
     }
 
+    sendDebugInfo(QString("origin = (%1, %2), target = (%3, %4), result flags = %5").arg(origin.x())
+                                                                                    .arg(origin.y())
+                                                                                    .arg(target.x())
+                                                                                    .arg(target.y())
+                                                                                    .arg((int)result));
 }
 
 void MGame::onMoveConfirmed()
@@ -373,22 +428,19 @@ void MGame::onMoveConfirmed()
     m_game.insert(m_half_move, m_trans_position);
 
     m_trans_captured_piece = 0;
-    deSelectPiece();
-    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED);
+    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED, true);
     updatePlayerStatus(m_trans_position);
     cleanupTransitionData();
 }
 
 void MGame::onPieceSelectionCancelled()
 {
-    setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED);
-    undoMove();
-    deSelectPiece();
+    onUndoMoveRequested();
 }
 
 void MGame::onUndoMoveRequested()
 {
     setActionAreaStates(MActionArea::TURN_ENDED, MActionArea::TURN_STARTED);
-    undoMove();
-    deSelectPiece();
+    undoTransitionalMove();
+    cleanupTransitionData();
 }
