@@ -22,17 +22,16 @@
 #ifndef GRAPHICS_BOARD_ITEM_H__
 #define GRAPHICS_BOARD_ITEM_H__
 
+#include "position.h"
+
 #include <QGraphicsItem>
 #include <QGraphicsSvgItem>
 #include <QGraphicsRectItem>
-#include <QTimeLine>
 #include <QGraphicsSceneMouseEvent>
 #include <QUrl>
 #include <QVector>
 #include <QPainter>
 
-#include <QTime>
-
 namespace Miniature
 {
 
@@ -47,7 +46,7 @@ class MGraphicsBoardItem
     Q_OBJECT
 
 public:
-    MGraphicsBoardItem(int board_size = 480, QGraphicsItem *parent = 0);
+    MGraphicsBoardItem(int board_size = 480, QGraphicsObject *parent = 0);
     ~MGraphicsBoardItem();
 
     // TODO: rename to cellSize(), more qt-ish
@@ -57,37 +56,18 @@ public:
     void virtual paint(QPainter*, const QStyleOptionGraphicsItem *, QWidget *) {}
     virtual QRectF boundingRect() const;
 
-    void addPiece(QGraphicsSvgItem *piece);
-    void removePieces();
+    void hidePieces();
 
 Q_SIGNALS:
-    void pieceMoveRequested(QPoint from, QPoint to);
-    void sendDebugInfo(QString msg);
+    void pieceClicked(MPiece *piece);
+    void targetClicked(const QPoint &cell);
+    void undoMoveRequest();
 
 protected:
     virtual void mousePressEvent(QGraphicsSceneMouseEvent *event);
 
 private:
-    void setupFrameAndTimeLine();
-    void resetFrame();
-    void putFrameAt(QPointF pos);
-
     const int m_board_size;
-    const int m_selection_duration;
-    QGraphicsRectItem *m_frame;
-    const int m_frame_outline;
-    QTimeLine *m_time_line;
-
-    // We need a safe way to remember the pieces on the board. This list acts
-    // as a filter, it stores all SVG items that represents pieces. I expect
-    // the scene graph and this class in particular to become very crowded once
-    // we start adding animations.
-    typedef QVector<QGraphicsSvgItem*> MPiecesList;
-    MPiecesList m_pieces;
-
-private Q_SLOTS:
-    /* Reduces opacity of the selection frame. */
-    void fadeOutFrame(int step);
 };
 
 };
