@@ -68,6 +68,11 @@ MMainWindow::MMainWindow()
     setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, true);
     setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, false);
 #endif
+
+#ifndef Q_WS_MAEMO_5
+    // TODO: Cant I just use this in general?
+    resize(480, -1);
+#endif
 }
 
 MMainWindow::~MMainWindow()
@@ -101,9 +106,13 @@ void MMainWindow::toggleDebugOutput()
 
 void MMainWindow::showAboutDialog()
 {
+    QFont font = QFont("helvetica", 14, QFont::Normal);
     QDialog dialog;
     m_about_dialog.setupUi(&dialog);
-    m_about_dialog.slogan->setFont(QFont("helvetica", 14, QFont::Normal));
+    m_about_dialog.slogan->setFont(font);
+    m_about_dialog.version->setFont(font);
+    m_about_dialog.version->setText(QString("%1: %2").arg(tr("Version"))
+                                                     .arg(PACKAGE_VERSION));
     dialog.exec();
 }
 
@@ -120,6 +129,11 @@ void MDBusAdaptor::top_application()
 
 int main(int argc, char ** argv)
 {
+    // the Qt docs warn of opengl as an experimental feature!
+#ifdef Q_WS_MAEMO_5
+    QApplication::setGraphicsSystem(QString("opengl"));
+#endif
+
     QApplication app(argc, argv);
     MMainWindow window;
 
